==> scummvm_2.7.0+dfsg.orig.tar.xz: scummvm-2.7.0+dfsg/image/codecs/msrle4.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef IMAGE_CODECS_MSRLE4_H
#define IMAGE_CODECS_MSRLE4_H

#include "image/codecs/codec.h"

namespace Image {

/**
 * Microsoft Run-Length Encoding decoder.
 *
 * Used by BMP/AVI.
 */
class MSRLE4Decoder : public Codec {
public:
	MSRLE4Decoder(uint16 width, uint16 height, byte bitsPerPixel);
	~MSRLE4Decoder();

	const Graphics::Surface *decodeFrame(Common::SeekableReadStream &stream);
	Graphics::PixelFormat getPixelFormat() const { return Graphics::PixelFormat::createFormatCLUT8(); }

private:
	byte _bitsPerPixel;

	Graphics::Surface *_surface;

	void decode4(Common::SeekableReadStream &stream);
};

} // End of namespace Image

#endif

==> scummvm_2026.1.0+dfsg.orig.tar.xz: scummvm-2026.1.0/image/codecs/msrle4.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef IMAGE_CODECS_MSRLE4_H
#define IMAGE_CODECS_MSRLE4_H

#include "image/codecs/codec.h"

namespace Image {

/**
 * Microsoft Run-Length Encoding decoder.
 *
 * Used by BMP/AVI.
 */
class MSRLE4Decoder : public Codec {
public:
	MSRLE4Decoder(uint16 width, uint16 height, byte bitsPerPixel);
	~MSRLE4Decoder() override;

	const Graphics::Surface *decodeFrame(Common::SeekableReadStream &stream) override;
	Graphics::PixelFormat getPixelFormat() const override { return Graphics::PixelFormat::createFormatCLUT8(); }

private:
	byte _bitsPerPixel;

	Graphics::Surface *_surface;

	void decode4(Common::SeekableReadStream &stream);
};

} // End of namespace Image

#endif
